==> haskell-wai-handler-launch-3.0.3.1-733-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-D1CUG3s6pFkI3UYKGaMUNk
key:                  wai-handler-launch-3.0.3.1-D1CUG3s6pFkI3UYKGaMUNk
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  ce03276f2514349dd73ad5f31880d509
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-D1CUG3s6pFkI3UYKGaMUNk
depends:
    async-2.2.5-KcBItHJGOZL2FAQS48vqcn base-4.17.2.1
    bytestring-0.11.5.3 http-types-0.12.4-1Pq1Zy5bmQBJRy3r5PsBE
    process-1.6.18.0 streaming-commons-0.2.3.0-1YmTvW5wH6w34JkUWjFadE
    transformers-0.5.6.2 wai-3.2.4-84onj9aucoXBC5yY5F84Os
    warp-3.3.30-9Zxn2kwWyMQK8cAG5JiXwE

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.3.1-734-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-4sKjKKHDpzn14UyS77kG9p
key:                  wai-handler-launch-3.0.3.1-4sKjKKHDpzn14UyS77kG9p
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  19cd05dbe735eca50c366c21341e7d83
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-4sKjKKHDpzn14UyS77kG9p
depends:
    async-2.2.5-KcBItHJGOZL2FAQS48vqcn base-4.17.2.1
    bytestring-0.11.5.3 http-types-0.12.4-1Pq1Zy5bmQBJRy3r5PsBE
    process-1.6.18.0 streaming-commons-0.2.3.0-1YmTvW5wH6w34JkUWjFadE
    transformers-0.5.6.2 wai-3.2.4-84onj9aucoXBC5yY5F84Os
    warp-3.3.30-F9UfVPtBJ5O9bZES7zmkIL

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
